==> paragraphs_blokkli-1.1.2.tar.gz: paragraphs_blokkli/modules/paragraphs_blokkli_graphql/src/Plugin/GraphQL/SchemaExtension/TransformExtension.php <==
<?php

namespace Drupal\paragraphs_blokkli_graphql\Plugin\GraphQL\SchemaExtension;

use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\graphql\GraphQL\ResolverBuilder;
use Drupal\graphql\GraphQL\ResolverRegistryInterface;
use Drupal\graphql\Plugin\GraphQL\SchemaExtension\SdlSchemaExtensionPluginBase;
use Drupal\paragraphs_blokkli_transform\ParagraphTransformInterface;
use Drupal\paragraphs_blokkli_transform\ParagraphTransformPluginManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A schema extension to add support for transform plugins.
 *
 * @SchemaExtension(
 *   id = "paragraphs_blokkli_transform",
 *   name = "Paragraphs Blokkli Transform",
 *   description = "Add support for transform plugins.",
 *   schema = "core_composable"
 * )
 */
class TransformExtension extends SdlSchemaExtensionPluginBase implements ContainerFactoryPluginInterface {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('module_handler'),
      $container->get('plugin.manager.paragraph_transform'),
    );
  }

  /**
   * The constructor.
   *
   * @param array $configuration
   *   The plugin configuration array.
   * @param string $pluginId
   *   The plugin id.
   * @param array $pluginDefinition
   *   The plugin definition array.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   The module handler service.
   * @param ParagraphTransformPluginManager $pluginManager
   *   The paragraph_transform plugin manager.
   */
  public function __construct(
    array $configuration,
    $pluginId,
    array $pluginDefinition,
    ModuleHandlerInterface $moduleHandler,
    protected ParagraphTransformPluginManager $pluginManager,
  ) {
    parent::__construct($configuration, $pluginId, $pluginDefinition, $moduleHandler);
  }

  /**
   * {@inheritdoc}
   */
  public function getEntityTypeDependencies() {
    return ['paragraph', 'paragraphs_type'];
  }

  /**
   * {@inheritdoc}
   */
  public function registerResolvers(ResolverRegistryInterface $registry): void {
    $builder = new ResolverBuilder();

    $registry->addFieldResolver(
      'Query',
      'paragraphsBlokkliGetTransformPlugins',
      $builder->cond([
        [
          $builder->produce('paragraphs_blokkli_can_use_blokkli'),
          $builder->callback(function () {
            $definitions = $this->pluginManager->getDefinitions();
            $plugins = [];

            foreach (array_keys($definitions) as $pluginId) {
              $plugins[] = $this->pluginManager->createInstance($pluginId);
            }

            return $plugins;
          }),
        ],
      ])
    );

    $registry->addFieldResolver(
      'ParagraphsBlokkliTransformPlugin',
      'id',
      $builder->callback(function (ParagraphTransformInterface $plugin) {
        return $plugin->pluginId;
      })
    );

    $registry->addFieldResolver(
      'ParagraphsBlokkliTransformPlugin',
      'label',
      $builder->callback(function (ParagraphTransformInterface $plugin) {
        return $plugin->label();
      })
    );

    $registry->addFieldResolver(
      'ParagraphsBlokkliTransformPlugin',
      'bundles',
      $builder->callback(function (ParagraphTransformInterface $plugin) {
        return $plugin->getBundles();
      })
    );

    $registry->addFieldResolver(
      'ParagraphsBlokkliTransformPlugin',
      'targetBundles',
      $builder->callback(function (ParagraphTransformInterface $plugin) {
        return $plugin->getTargetBundles();
      })
    );

    $registry->addFieldResolver(
      'ParagraphsBlokkliTransformPlugin',
      'min',
      $builder->callback(function (ParagraphTransformInterface $plugin) {
        return $plugin->getMin();
      })
    );

    $registry->addFieldResolver(
      'ParagraphsBlokkliTransformPlugin',
      'max',
      $builder->callback(function (ParagraphTransformInterface $plugin) {
        return $plugin->getMax();
      })
    );
  }

}

==> paragraphs_blokkli-1.3.0.tar.gz: paragraphs_blokkli/modules/paragraphs_blokkli_graphql/src/Plugin/GraphQL/SchemaExtension/TransformExtension.php <==
<?php

namespace Drupal\paragraphs_blokkli_graphql\Plugin\GraphQL\SchemaExtension;

use Drupal\graphql\GraphQL\ResolverBuilder;
use Drupal\graphql\GraphQL\ResolverRegistryInterface;
use Drupal\graphql\Plugin\GraphQL\SchemaExtension\SdlSchemaExtensionPluginBase;
use Drupal\paragraphs_blokkli_transform\ParagraphTransformInterface;

/**
 * A schema extension to add support for transform plugins.
 *
 * @SchemaExtension(
 *   id = "paragraphs_blokkli_transform",
 *   name = "Paragraphs Blokkli Transform",
 *   description = "Add support for transform plugins.",
 *   schema = "core_composable"
 * )
 */
class TransformExtension extends SdlSchemaExtensionPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getEntityTypeDependencies() {
    return ['paragraph', 'paragraphs_type'];
  }

  /**
   * {@inheritdoc}
   */
  public function registerResolvers(ResolverRegistryInterface $registry): void {
    $builder = new ResolverBuilder();

    $registry->addFieldResolver(
      'Query',
      'paragraphsBlokkliGetTransformPlugins',
      $builder->cond([
        [
          $builder->produce('paragraphs_blokkli_can_use_blokkli'),
          $builder->compose(
            $builder->produce('paragraphs_blokkli_load_host_entity')
              ->map('entityType', $builder->fromArgument('entityType'))
              ->map('entityUuid', $builder->fromArgument('entityUuid'))
              ->map('langcode', $builder->fromArgument('langcode')),
            $builder->produce('paragraphs_blokkli_transform_plugins')
              ->map('entity', $builder->fromParent())
              ->map('langcode', $builder->fromArgument('langcode')),
          ),
        ],
      ])
    );

    $registry->addFieldResolver(
      'ParagraphsBlokkliTransformPlugin',
      'id',
      $builder->callback(function (ParagraphTransformInterface $plugin) {
        return $plugin->pluginId;
      })
    );

    $registry->addFieldResolver(
      'ParagraphsBlokkliTransformPlugin',
      'label',
      $builder->callback(function (ParagraphTransformInterface $plugin) {
        return $plugin->label();
      })
    );

    $registry->addFieldResolver(
      'ParagraphsBlokkliTransformPlugin',
      'bundles',
      $builder->callback(function (ParagraphTransformInterface $plugin) {
        return $plugin->getBundles();
      })
    );

    $registry->addFieldResolver(
      'ParagraphsBlokkliTransformPlugin',
      'targetBundles',
      $builder->callback(function (ParagraphTransformInterface $plugin) {
        return $plugin->getTargetBundles();
      })
    );

    $registry->addFieldResolver(
      'ParagraphsBlokkliTransformPlugin',
      'min',
      $builder->callback(function (ParagraphTransformInterface $plugin) {
        return $plugin->getMin();
      })
    );

    $registry->addFieldResolver(
      'ParagraphsBlokkliTransformPlugin',
      'max',
      $builder->callback(function (ParagraphTransformInterface $plugin) {
        return $plugin->getMax();
      })
    );
  }

}
